getBridgeFile <- function(basename) {
  dir <- Sys.getenv("R_XMAP_BRIDGE_CACHE")
  if(dir == "") {
     stop("Don't know where the X:MAP bridge cache is: environment variable R_XMAP_BRIDGE_CACHE is not set.")
  }
  
  file.path(dir,paste(basename,".xmap",sep=""))
}

.writeBridgeData <- function(filename,geneid,description,species,type="int",data,colours,overwrite=FALSE,ylim) {
  if(missing(filename)) { stop("Must specify a filename")}
  if(missing(geneid))   { stop("Must specify a geneid")}
  if(missing(species))  { stop("Must specify a species")}
  if(missing(data))     { stop("Must provide data")}
  if(is.null(colnames(data))) { stop("Data must have column names")}
  if(file.exists(filename) && !overwrite) {
      stop(paste("Filename",filename,"already exists. Not overwriting."))
  }
  else {
    fl <- file(filename,"w")
    if(!isOpen(fl)) { stop(paste("Couldn't open file",filename,"\n.")) }
    if(!exists(description)){
      description <- paste(geneid,"expression data")
    }
    if(type=="int") { type <- "ex" }
    else            { type <- "fc" }

    writeLines(paste(description,geneid,species,type,ylim[1],ylim[2],sep="\t"),fl)
    writeLines(paste(colnames(data),collapse="\t"),fl)
    if(missing(colours)) {
      colours <- rainbow(length(colnames(data)),gamma=0.5)
      colours <- sapply(colours,function(a) { substr(a,1,7) })
    }
    if(length(colours) != length(colnames(data))) {
      stop("colours must be the same length as the number of columns in 'data'")
    }
    writeLines(paste(colours,collapse="\t"),fl)
    write.table(data, file = fl, append = TRUE, quote = FALSE, sep = "\t",
                 eol = "\n", na = "NA", dec = ".", row.names = TRUE,
                 col.names = FALSE)
    flush(fl)
    close(fl)
  }
}


xmapBridge <- function(x,eset,colours,bridge.file=getBridgeFile(x),description="exonmap expression data",
                       gps,type=c("fc","int"),
                       overwrite=FALSE,show.introns=TRUE,show.mt=FALSE,open.browser=FALSE,ylim) {
  data <-  gene.details(x)
  if (dim(data)[1]>1) stop("Ambiguous gene!\n")
  if (dim(data)[1]==0) stop("Gene not found!\n")

  psets <- gene.to.probeset(x)
  if(!show.introns){
    psets <- select.probewise(psets,"exonic")
  }
  if(!show.mt){
    psets <- exclude.probewise(psets,"multitarget")
  }
  exp.data <- exprs(eset)[psets,,drop=FALSE]

  if(dim(exp.data)[1]<1) { stop("no matching probesets found!") }

  if(!missing(gps) && !missing(colours)){
    if(length(gps) != length(colours)) {
      stop("Colours must be the same length as groups")
    }
  }
  if(!missing(gps)) {
    if((type=="mean-fc" && length(gps)!=2) ||
       (type=="min-fc" && length(gps)!=2) ||
       (type=="max-fc" && length(gps)!=2)) {
      stop("If fold change calculation specified, number of groups must be exactly two")
    }
    
    gp1 <- gps[[1]]
    gp2 <- gps[[2]]
    
    type <- match.arg(type)
    
    rn <- rownames(exp.data)

    if(type == "fc") {
      exp.data <- matrix(apply(exp.data,1,function(d) {
        (mean(d[gp1])-mean(d[gp2]))}),ncol=1)
      colnames(exp.data) <- paste(names(gps)[1],"-",names(gps)[2])
    }
      else {
        exp.data <- t(apply(exp.data,1,function(d) {
          sapply(gps,function(a){mean(d[a])})
        }))
        nms <- names(gps)
        if(is.null(nms)) {
          nms <- 1:length(gps)
        }
        colnames(exp.data) <- nms
      }
    rownames(exp.data) <- rn
  }
  else {
    stop("Must specify which arrays to plot, using 'gps'")
  }
  if(missing(ylim)) {
    if(type=="fc") {
      ylim <- c(-5,5)
    }
    else {
      ylim <- c(0,14)
    }
  }
  exp.data[exp.data < ylim[1]] <- ylim[1]
  exp.data[exp.data > ylim[2]] <- ylim[2]
  if(!exists(".ExonmapSpecies")) {
    stop("species not specified - must be in the exonmap config file. See ?xmapBridge for more details.")
  }
  .writeBridgeData(bridge.file,x,description,species=.ExonmapSpecies,type,exp.data,colours,overwrite,ylim)

  if(open.browser) {
    if (dim(data)[1]==1) {
      startpoint <- data[1,"seq_region_start"]
      chr <- data[1,"name"]
      
      myurl <- paste ("http://xmap.picr.man.ac.uk/#",chr,"/x",startpoint,"/16/h", sep="")
        browseURL(myurl) 
    }
  }
}


xmapGene <- function(x) {
  proc <- paste ("CALL xmap_geneDetails('",x,"')",sep="")
  data <-  .doStoredProcedureFetch( proc )
  if (dim(data)[1]==1) {
    startpoint <- data[1,"seq_region_start"]
    chr <- data[1,"name"]
    myurl <- paste ("http://xmap.picr.man.ac.uk/#",chr,"/x",startpoint,"/16/h", sep="")
      browseURL(myurl) 
  }
  if (dim(data)[1]>1) cat ("Ambiguous transcript!\n")
  if (dim(data)[1]==0) cat ("Transcript not found!\n")
}


##################################################################################################
xmapTranscript <- function(x)
{
  proc <- paste ("CALL xmap_transcriptDetails('",x,"')",sep="")
  data <-  .doStoredProcedureFetch( proc )
  if (dim(data)[1]==1) {
    startpoint <- data[1,"seq_region_start"]
    chr <- data[1,"name"]
    myurl <- paste ("http://xmap.picr.man.ac.uk/#",chr,"/x",startpoint,"/16/h", sep="")
      browseURL(myurl) 
  }
  if (dim(data)[1]>1) cat ("Ambiguous transcript!\n")
  if (dim(data)[1]==0) cat ("Transcript not found!\n")
}
##################################################################################################
xmapExon <- function(x)
{
  proc <- paste ("CALL xmap_exonDetails('",x,"')",sep="")
  data <-  .doStoredProcedureFetch( proc )
  if (dim(data)[1]==1)
    {
      startpoint <- data[1,"seq_region_start"]
      chr <- data[1,"name"]
      myurl <- paste ("http://xmap.picr.man.ac.uk/#",chr,"/x",startpoint,"/16/h", sep="")
        browseURL(myurl) 
    }
  if (dim(data)[1]>1) cat ("Ambiguous exon!\n")
  if (dim(data)[1]==0) cat ("Exon not found!\n")
}
##################################################################################################
xmapProbeset <- function(x) {

  MyQuery <- paste("select ps.name, sr.name as chr, max(psum.total_hits) as th, min(h.seq_region_start) as start, max(h.seq_region_end) as stop from probeset ps LEFT JOIN probemap pm USING (probeset_id) LEFT JOIN probe_summary psum USING(probe_id) LEFT JOIN hit h USING (probe_id) LEFT JOIN seq_region sr USING (seq_region_id) WHERE ps.name='",x,"' group by sr.name ;", sep="")
  res <- dbSendQuery(MyQuery)
  data <- fetch(res, n=-1)
  if (dim(data)[1]==1 & data[1,"th"]<10)
    {
      startpoint <- data[1,"start"]
      chr <- data[1,"chr"]
      myurl <- paste ("http://xmap.picr.man.ac.uk/#",chr,"/x",startpoint,"/16/h", sep="")
        browseURL(myurl) 
    }
  if (dim(data)[1]>1 | data[1,"th"]>=10 ) cat ("Ambiguous probeset!\n")
  if (dim(data)[1]==0) cat ("Probeset not found!\n")
}

